@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -42,6 +42,18 @@ has pool => (
 );
 
 
+has pool_code => (
+    is      => 'rw',
+    builder => 1,
+    lazy    => 1,
+);
+
+sub _build_pool_code {
+    my ($self) = @_;
+    return sub { return $self->pool->[ int rand @{ $self->pool } ] };
+};
+
+
 has min_size => (
     is       => 'ro',
     builder  => 1,
@@ -78,7 +90,7 @@ sub motif {
     my $sum = 0;
 
     while ( $sum < $self->size ) {
-        my $name = $self->pool->[ int rand @{ $self->pool } ];
+        my $name = $self->pool_code->();
         my $size = $self->duration($name);
         my $diff = $self->size - $sum;
         last
@@ -110,7 +122,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -121,6 +133,8 @@ version 0.0200
     pool => [qw/ qn en sn /],
   );
 
+  $mdp->pool_code( sub { ... } );
+
   my $motif = $mdp->motif;
 
   my $notes = get_notes($motif); # Your imaginary note generator
@@ -174,6 +188,15 @@ motif.
 
 Default: C<[ keys %MIDI::Simple::Length ]>
 
+=head2 pool_code
+
+  $name = $mdp->pool_code->();
+  $mdp->pool_code( sub { ... } );
+
+A code reference to select an item from the given duration B<pool>.
+
+Default: Random item of B<pool>
+
 =head2 min_size
 
   $min_size = $mdp->min_size;
@@ -212,11 +235,13 @@ loop until the B<size> is met.
 
 =head1 TO DO
 
-Give ->motif a code reference to select a pool duration instead of "at random."
+Give ->motif a code reference to select a pool duration instead of "at
+random."
 
 =head1 SEE ALSO
 
-The F<t/01-methods.t> and F<eg/motif> code in this distribution.
+The F<t/01-methods.t>, F<eg/motif> and F<eg/shuffle> code in this
+distribution.
 
 L<List::Util>
 
